@@ -21,14 +21,47 @@ extern "C" {
 #include <stdlib.h>
 #include <stdio.h>
 
+/**
+ * @brief SVT-AV1 encoder ABI version
+ *
+ * Should be increased by 1 everytime a public struct in the encoder
+ * has been modified, and reset anytime the major API version has
+ * been changed. Used to keep track if a field has been added or not.
+ */
+#define SVT_AV1_ENC_ABI_VERSION 4
+
 //***HME***
 
 #define MAX_HIERARCHICAL_LEVEL 6
 #define REF_LIST_MAX_DEPTH 4
-#define MAX_ENC_PRESET 13
-#define NUM_MV_COMPONENTS 2
-#define NUM_MV_HIST 2
-#define MAX_MV_HIST_SIZE 2 * REF_LIST_MAX_DEPTH *NUM_MV_COMPONENTS *NUM_MV_HIST
+/*!\brief Decorator indicating that given struct/union/enum is packed */
+#ifndef ATTRIBUTE_PACKED
+#if defined(__GNUC__) && __GNUC__
+#define ATTRIBUTE_PACKED __attribute__((packed))
+#else
+#define ATTRIBUTE_PACKED
+#endif
+#endif /* ATTRIBUTE_PACKED */
+typedef enum ATTRIBUTE_PACKED {
+    ENC_MRS        = -2, // Highest quality research mode (slowest)
+    ENC_MR         = -1, //Research mode with higher quality than M0
+    ENC_M0         = 0,
+    ENC_M1         = 1,
+    ENC_M2         = 2,
+    ENC_M3         = 3,
+    ENC_M4         = 4,
+    ENC_M5         = 5,
+    ENC_M6         = 6,
+    ENC_M7         = 7,
+    ENC_M8         = 8,
+    ENC_M9         = 9,
+    ENC_M10        = 10,
+    ENC_M11        = 11,
+    ENC_M12        = 12,
+    ENC_M13        = 13,
+    MAX_ENC_PRESET = ENC_M13
+} EncMode;
+
 #define DEFAULT -1
 
 #define EB_BUFFERFLAG_EOS 0x00000001 // signals the last packet of the stream
@@ -102,6 +135,16 @@ typedef enum {
     SUPERRES_AUTO_SEARCH_TYPES
 } SUPERRES_AUTO_SEARCH_TYPE;
 
+// reference scaling modes
+typedef enum {
+    RESIZE_NONE, // No frame resize allowed.
+    RESIZE_FIXED, // All frames are coded at the specified scale.
+    RESIZE_RANDOM, // All frames are coded at a random scale.
+    RESIZE_DYNAMIC, // Resize scale for a frame in dynamic.
+    RESIZE_RANDOM_ACCESS, // Resize scale frame by event in random access
+    RESIZE_MODES
+} RESIZE_MODE;
+
 /** The SvtAv1IntraRefreshType is used to describe the intra refresh type.
 */
 typedef enum SvtAv1IntraRefreshType {
@@ -125,11 +168,18 @@ typedef struct SvtAv1FixedBuf {
     uint64_t sz; /**< Length of the buffer, in chars */
 } SvtAv1FixedBuf; /**< alias for struct aom_fixed_buf */
 
+/** Indicates how an S-Frame should be inserted.
+*/
+typedef enum EbSFrameMode {
+    SFRAME_STRICT_BASE =
+        1, /**< The considered frame will be made into an S-Frame only if it is a base layer inter frame */
+    SFRAME_NEAREST_BASE =
+        2, /**< If the considered frame is not an altref frame, the next base layer inter frame will be made into an S-Frame */
+} EbSFrameMode;
+
 // Will contain the EbEncApi which will live in the EncHandle class
 // Only modifiable during config-time.
 typedef struct EbSvtAv1EncConfiguration {
-    // Encoding preset
-
     /**
      * @brief Encoder preset used.
      * -2 and -1 are for debug purposes and should not be used.
@@ -146,14 +196,17 @@ typedef struct EbSvtAv1EncConfiguration {
 
     /* The intra period defines the interval of frames after which you insert an
      * Intra refresh. It is strongly recommended to set the value to multiple of
-     * 8 minus 1 the closest to 1 second (e.g. 55, 47, 31, 23 should be used for
-     * 60, 50, 30, (24 or 25) respectively.
+     * 2^(hierarchical_levels), subtracting one if using open GOP (intra_refresh_type == 1).
+     * For instance, to get a 5-second GOP (default being >=5 seconds)
+     * with hierarchical_levels = 3 and open GOP you could use 319, 279, 159
+     * for 60, 50, or 30 respectively.
      *
      * -1 = no intra update.
      * -2 = auto.
      *
      * Default is -2. */
     int32_t intra_period_length;
+
     /* Random access.
      *
      * 1 = CRA, open GOP.
@@ -205,15 +258,13 @@ typedef struct EbSvtAv1EncConfiguration {
      */
     uint32_t source_height;
 
-    /* The frequecy of images being displayed. If the number is less than 1000,
-     * the input frame rate is an integer number between 1 and 60, else the input
-     * number is in Q16 format, shifted by 16 bits, where max allowed is 240 fps.
-     * If FrameRateNumerator and FrameRateDenominator are both not equal to zero,
-     * the encoder will ignore this parameter.
-     *
-     * Default is 25. */
-    uint32_t frame_rate;
-
+    /* Specifies the maximum frame width/height for the frames represented by the sequence header
+     * (max_frame_width_minus_1 and max_frame_height_minus_1, spec 5.5.1).
+     * Actual frame height could be equal to or less than this value. E.g. Use this value to indicate
+     * the maximum height between renditions when switch frame feature is on.
+     */
+    uint32_t forced_max_frame_width;
+    uint32_t forced_max_frame_height;
     /* Frame rate numerator. When zero, the encoder will use -fps if
      * FrameRateDenominator is also zero, otherwise an error is returned.
      *
@@ -246,10 +297,96 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is 0. */
     uint32_t compressed_ten_bit_format;
 
-    /* Instruct the library to calculate the recon to source for PSNR calculation
+    /**
+     * @brief Enable writing of HDR metadata in the bitstream
+     *
+     * Default is false.
+     */
+    Bool high_dynamic_range_input;
+
+    /**
+     * @brief Bitstream profile to use.
+     * 0: main, 1: high, 2: professional.
+     *
+     * Min is MAIN_PROFILE.
+     * Max is PROFESSIONAL_PROFILE.
+     * Default is MAIN_PROFILE.
+     */
+    EbAv1SeqProfile profile;
+    /* Constraints for bitstream in terms of max bitrate and max buffer size.
+     *
+     * 0 = Main, for most applications.
+     * 1 = High, for demanding applications.
+     *
+     * Default is 0. */
+    uint32_t tier;
+
+    /**
+     * @brief Bitstream level.
+     * 0: autodetect from bitstream, 20: level 2.0, 63: level 6.3, only levels 2.0-6.3 are properly defined.
+     * The levels are defined at https://aomediacodec.github.io/av1-spec/av1-spec.pdf
+     * under "A.3. Levels".
+     *
+     * Min is 0.
+     * Max is 73.
+     * Default is 0.
+     */
+    uint32_t level;
+
+    /* Color description present flag
     *
-    * Default is 0.*/
-    uint32_t stat_report;
+    * It is not necessary to set this parameter manually.
+    * It is set internally to true once one of the color_primaries, transfer_characteristics or
+    * matrix coefficients is set to non-default value.
+    *
+    Default is false. */
+    Bool color_description_present_flag;
+    /* Color primaries
+    * values are from EbColorPrimaries
+    Default is 2 (CP_UNSPECIFIED). */
+    EbColorPrimaries color_primaries;
+    /* Transfer characteristics
+    * values are from EbTransferCharacteristics
+    Default is 2 (TC_UNSPECIFIED). */
+    EbTransferCharacteristics transfer_characteristics;
+    /* Matrix coefficients
+    * values are from EbMatrixCoefficients
+    Default is 2 (MC_UNSPECIFIED). */
+    EbMatrixCoefficients matrix_coefficients;
+    /* Color range
+    * values are from EbColorRange
+    * 0: studio swing.
+    * 1: full swing.
+    Default is 0. */
+    EbColorRange color_range;
+    /* Mastering display metadata
+    * values are from set using svt_aom_parse_mastering_display()
+    */
+    struct EbSvtAv1MasteringDisplayInfo mastering_display;
+    /* Content light level
+    * values are from set using svt_aom_parse_content_light_level()
+    */
+    struct EbContentLightLevel content_light_level;
+
+    /* Chroma sample position
+     * Values as per 6.4.2 of the specification:
+     * EB_CSP_UNKNOWN:   default
+     * EB_CSP_VERTICAL:  value 0 from H.273 AKA "left"
+     * EB_CSP_COLOCATED: value 2 from H.273 AKA "top left"
+     */
+    EbChromaSamplePosition chroma_sample_position;
+
+    // End input info
+
+    /* Rate control mode.
+     *
+     * 0 = Constant QP.
+     * 1 = Variable Bit Rate, achieve the target bitrate at entire stream.
+     * 2 = Constant Bit Rate, achieve the target bitrate
+     * Default is 0. */
+    uint32_t rate_control_mode;
+
+    // Rate control tuning
 
     // Quantization
     /* Initial quantization parameter for the Intra pictures used under constant
@@ -261,92 +398,23 @@ typedef struct EbSvtAv1EncConfiguration {
     /* force qp values for every picture that are passed in the header pointer
     *
     * Default is 0.*/
-    EbBool use_qp_file;
+    Bool use_qp_file;
 
-    /* use fixed qp offset for every picture based on temporal layer index
-    *
-    * Default is 0.*/
-    EbBool  use_fixed_qindex_offsets;
-    int32_t qindex_offsets[EB_MAX_TEMPORAL_LAYERS];
-    int32_t key_frame_chroma_qindex_offset;
-    int32_t key_frame_qindex_offset;
-    int32_t chroma_qindex_offsets[EB_MAX_TEMPORAL_LAYERS];
-
-    // input / output buffer to be used for multi-pass encoding
-    SvtAv1FixedBuf rc_stats_buffer;
-    int            pass;
-
-    // Deblock Filter
-
-    /**
-     * @brief Deblocking loop filter control
+    /* Target bitrate in bits/second, only applicable when rate control mode is
+     * set to 1 (VBR) or 2 (CBR).
      *
-     * Default is true.
-     */
-    EbBool enable_dlf_flag;
-
-    /* Film grain denoising the input picture
-    * Flag to enable the denoising
-    *
-    * Default is 0. */
-    uint32_t film_grain_denoise_strength;
-
-    /* CDEF Level
-    *
-    * Default is -1. */
-    int cdef_level;
-
-    /* Restoration filtering
-    *  enable/disable
-    *  set Self-Guided (sg) mode
-    *  set Wiener (wn) mode
-    *
-    * Default is -1. */
-    int enable_restoration_filtering;
-    /* motion field motion vector
-    *
-    *  Default is -1. */
-    int enable_mfmv;
-
-    // Rate Control
-
-    /* Rate control mode.
-     *
-     * 0 = Constant QP.
-     * 1 = Variable Bit Rate, achieve the target bitrate at entire stream.
-     * 2 = Constrained Variable Bit Rate, achieve the target bitrate at each gop
-     * Default is 0. */
-    uint32_t rate_control_mode;
-    /* Flag to enable the scene change detection algorithm.
-     *
-     * Default is 1. */
-    uint32_t scene_change_detection;
-
-    /* When RateControlMode is set to 1 it's best to set this parameter to be
-     * equal to the Intra period value (such is the default set by the encoder).
-     * When CQP is chosen, then a (2 * minigopsize +1) look ahead is recommended.
-     *
-     * Default depends on rate control mode.*/
-    uint32_t look_ahead_distance;
-
-    /* Enable TPL in look ahead
-     * 0 = disable TPL in look ahead
-     * 1 = enable TPL in look ahead
-     * Default is 0  */
-    uint8_t enable_tpl_la;
-
-    /* Target bitrate in bits/second, only apllicable when rate control mode is
-     * set to 2 or 3.
-     *
-     * Default is 7000000. */
+     * Default is 2000000. */
     uint32_t target_bit_rate;
     /* maximum bitrate in bits/second, only apllicable when rate control mode is
      * set to 0.
      *
      * Default is 0. */
     uint32_t max_bit_rate;
-    /* VBV Buffer size */
+
+#if !SVT_AV1_CHECK_VERSION(1, 3, 0)
+    /* DEPRECATED: to be removed in 1.3.0. */
     uint32_t vbv_bufsize;
+#endif
 
     /* Maxium QP value allowed for rate control use, only applicable when rate
      * control mode is set to 1. It has to be greater or equal to minQpAllowed.
@@ -359,7 +427,7 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is 0. */
     uint32_t min_qp_allowed;
 
-    /* TWO PASS DATARATE CONTROL OPTIONS.
+    /* DATARATE CONTROL OPTIONS.
      * Indicates the bias (expressed on a scale of 0 to 100) for determining
      * target size for the current frame. The value 0 indicates the optimal CBR
      * mode value should be used, and 100 indicates the optimal VBR mode value
@@ -394,6 +462,101 @@ typedef struct EbSvtAv1EncConfiguration {
      * application, and is expressed in units of time(milliseconds).*/
     int64_t maximum_buffer_size_ms;
 
+    // input / output buffer to be used for multi-pass encoding
+    SvtAv1FixedBuf rc_stats_buffer;
+    int            pass;
+
+    // End rate control tuning
+
+    // Individual tuning flags
+    /* use fixed qp offset for every picture based on temporal layer index
+    * 0: off (use the auto mode QP)
+    * 1: on (the offset is applied on top of the user QP)
+    * 2: on (the offset is applied on top of the auto mode QP)
+    *
+    * Default is 0.*/
+    uint8_t use_fixed_qindex_offsets;
+    int32_t qindex_offsets[EB_MAX_TEMPORAL_LAYERS];
+    int32_t key_frame_chroma_qindex_offset;
+    int32_t key_frame_qindex_offset;
+    int32_t chroma_qindex_offsets[EB_MAX_TEMPORAL_LAYERS];
+
+    int32_t luma_y_dc_qindex_offset;
+    int32_t chroma_u_dc_qindex_offset;
+    int32_t chroma_u_ac_qindex_offset;
+    int32_t chroma_v_dc_qindex_offset;
+    int32_t chroma_v_ac_qindex_offset;
+
+    /**
+     * @brief Deblocking loop filter control
+     *
+     * Default is true.
+     */
+    Bool enable_dlf_flag;
+
+    /* Film grain denoising the input picture
+    * Flag to enable the denoising
+    *
+    * Default is 0. */
+    uint32_t film_grain_denoise_strength;
+
+    /**
+    * @brief Determines how much denoising is used.
+    * Only applicable when film grain is ON.
+    *
+    * 0 is no denoising
+    * 1 is full denoising
+    */
+    uint8_t film_grain_denoise_apply;
+
+    /* CDEF Level
+    *
+    * Default is -1. */
+    int cdef_level;
+
+    /* Restoration filtering
+    *  enable/disable
+    *  set Self-Guided (sg) mode
+    *  set Wiener (wn) mode
+    *
+    * Default is -1. */
+    int enable_restoration_filtering;
+    /* motion field motion vector
+    *
+    *  Default is -1. */
+    int enable_mfmv;
+
+    /* Flag to enable the scene change detection algorithm.
+     *
+     * Default is 1. */
+    uint32_t scene_change_detection;
+
+    /**
+     * @brief API signal to constrain motion vectors.
+     *
+     * Default is false.
+     */
+    Bool restricted_motion_vector;
+
+    /* Log 2 Tile Rows and columns . 0 means no tiling,1 means that we split the dimension
+        * into 2
+        * Default is 0. */
+    int32_t tile_columns;
+    int32_t tile_rows;
+
+    /* When RateControlMode is set to 1 it's best to set this parameter to be
+     * equal to the Intra period value (such is the default set by the encoder).
+     * When CQP is chosen, then a (2 * minigopsize +1) look ahead is recommended.
+     *
+     * Default depends on rate control mode.*/
+    uint32_t look_ahead_distance;
+
+    /* Enable TPL in look ahead
+     * 0 = disable TPL in look ahead
+     * 1 = enable TPL in look ahead
+     * Default is 0  */
+    uint8_t enable_tpl_la;
+
     /* recode_loop indicates the recode levels,
      * DISALLOW_RECODE = 0, No recode.
      * ALLOW_RECODE_KFMAXBW = 1, Allow recode for KF and exceeding maximum frame bandwidth.
@@ -412,50 +575,76 @@ typedef struct EbSvtAv1EncConfiguration {
 
     /* Enable adaptive quantization within a frame using segmentation.
      *
+     * For rate control mode 0, setting this to 0 will use CQP mode, else CRF mode will be used.
      * Default is 2. */
     uint8_t enable_adaptive_quantization;
 
-    // Tresholds
+    /**
+     * @brief Enable use of ALT-REF (temporally filtered) frames.
+     *
+     * Default is true.
+     */
+    Bool enable_tf;
+
+    Bool enable_overlays;
+    /**
+     * @brief Tune for a particular metric; 0: VQ, 1: PSNR
+     *
+     * Default is 1.
+     */
+    uint8_t tune;
+
+    // super-resolution parameters
+    uint8_t superres_mode;
+    uint8_t superres_denom;
+    uint8_t superres_kf_denom;
+    uint8_t superres_qthres;
+    uint8_t superres_kf_qthres;
+    uint8_t superres_auto_search_type;
 
     /**
-     * @brief Enable writing of HDR metadata in the bitstream
+     * @brief API signal containing the manual prediction structure parameters.
+     * Only used when enable_manual_pred_struct is enabled. This list is copied
+     * into internal buffers after svt_av1_enc_set_parameter().
+     */
+    PredictionStructureConfigEntry pred_struct[1 << (MAX_HIERARCHICAL_LEVEL - 1)];
+
+    /**
+     * @brief API signal to overwrite the encoder's default prediction structure.
      *
      * Default is false.
      */
-    EbBool high_dynamic_range_input;
+    Bool enable_manual_pred_struct;
 
     /**
-     * @brief Bitstream profile to use.
-     * 0: main, 1: high, 2: professional.
+     * @brief API signal specifying the size (number of entries) of the manual prediction structure buffer.
+     * Only checked and used when enable_manual_pred_struct is enabled.
      *
-     * Min is MAIN_PROFILE.
-     * Max is PROFESSIONAL_PROFILE.
-     * Default is MAIN_PROFILE.
-     */
-    EbAv1SeqProfile profile;
-    /* Constraints for bitstream in terms of max bitrate and max buffer size.
-     *
-     * 0 = Main, for most applications.
-     * 1 = High, for demanding applications.
-     *
-     * Default is 0. */
-    uint32_t tier;
-
-    /**
-     * @brief Bitstream level.
-     * 0: autodetect from bitstream, 20: level 2.0, 63: level 6.3, only levels 2.0-6.3 are properly defined.
-     * The levels are defined at https://aomediacodec.github.io/av1-spec/av1-spec.pdf
-     * under "A.3. Levels".
-     *
-     * Min is 0.
-     * Max is 73.
+     * Min is 1.
+     * Max is 32.
      * Default is 0.
      */
-    uint32_t level;
+    int32_t manual_pred_struct_entry_num;
 
-    /* CPU FLAGS to limit assembly instruction set used by encoder.
-    * Default is CPU_FLAGS_ALL. */
-    CPU_FLAGS use_cpu_flags;
+    /* Decoder-speed-targeted encoder optimization level (produce bitstreams that can be decoded faster).
+    * 0: No decoder speed optimization
+    * 1: Decoder speed optimization enabled (fast decode)
+    */
+    Bool fast_decode;
+
+    /* S-Frame interval (frames)
+    * 0: S-Frame off
+    * >0: S-Frame on and indicates the number of frames after which a frame may be coded as an S-Frame
+    */
+    int32_t sframe_dist;
+    /* Indicates how an S-Frame should be inserted
+    * values are from EbSFrameMode
+    * SFRAME_STRICT_ARF: the considered frame will be made into an S-Frame only if it is an altref frame
+    * SFRAME_NEAREST_ARF: if the considered frame is not an altref frame, the next altref frame will be made into an S-Frame
+    */
+    EbSFrameMode sframe_mode;
+
+    // End of individual tuning flags
 
     // Application Specific parameters
 
@@ -477,13 +666,6 @@ typedef struct EbSvtAv1EncConfiguration {
      */
     uint32_t active_channel_count;
 
-    /**
-     * @brief API signal to constrain motion vectors.
-     *
-     * Default is false.
-     */
-    EbBool restricted_motion_vector;
-
     // Threads management
 
     /* The number of logical processor which encoder threads run on. If
@@ -509,7 +691,15 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is -1. */
     int32_t target_socket;
 
+    /* CPU FLAGS to limit assembly instruction set used by encoder.
+    * Default is EB_CPU_FLAGS_ALL. */
+    EbCpuFlags use_cpu_flags;
+
     // Debug tools
+    /* Instruct the library to calculate the recon to source for PSNR calculation
+    *
+    * Default is 0.*/
+    uint32_t stat_report;
 
     /**
      * @brief API Signal to output reconstructed yuv used for debug purposes.
@@ -517,102 +707,59 @@ typedef struct EbSvtAv1EncConfiguration {
      *
      * Default is false.
      */
-    EbBool recon_enabled;
-
-    /* Log 2 Tile Rows and colums . 0 means no tiling,1 means that we split the dimension
-        * into 2
-        * Default is 0. */
-    int32_t tile_columns;
-    int32_t tile_rows;
+    Bool recon_enabled;
+    // 1.0.0: Any additional fields shall go after here
 
     /**
-     * @brief Enable use of ALT-REF (temporally filtered) frames.
+     * @brief Signal that force-key-frames is enabled.
      *
-     * Default is true.
      */
-    EbBool enable_tf;
-
-    EbBool enable_overlays;
-    /**
-     * @brief Tune for a particular metric; 0: VQ, 1: PSNR
-     *
-     * Default is 1.
-     */
-    uint8_t tune;
-    // super-resolution parameters
-    uint8_t superres_mode;
-    uint8_t superres_denom;
-    uint8_t superres_kf_denom;
-    uint8_t superres_qthres;
-    uint8_t superres_kf_qthres;
-    uint8_t superres_auto_search_type;
+    Bool force_key_frames;
 
     /**
-     * @brief API signal containing the manual prediction structure parameters.
-     * Only used when enable_manual_pred_struct is enabled. This list is copied
-     * into internal buffers after svt_av1_enc_set_parameter().
+     * @brief Signal to the library to treat intra_period_length as seconds and
+     * multiply by fps_num/fps_den.
      */
-    PredictionStructureConfigEntry pred_struct[1 << (MAX_HIERARCHICAL_LEVEL - 1)];
+    Bool multiply_keyint;
 
+    // reference scaling parameters
     /**
-     * @brief API signal to overwrite the encoder's default prediction structure.
+     * @brief Reference scaling mode
+     * the available modes are defined in RESIZE_MODE
+     */
+    uint8_t resize_mode;
+    /**
+     * @brief Resize denominator
+     * this value can be from 8 to 16, means downscaling to 8/8-8/16 of original
+     * resolution in both width and height
+     */
+    uint8_t resize_denom;
+    /**
+     * @brief Resize denominator of key frames
+     * this value can be from 8 to 16, means downscaling to 8/8-8/16 of original
+     * resolution in both width and height
+     */
+    uint8_t resize_kf_denom;
+    /**
+     * @brief Signal to the library to enable quantisation matrices
      *
      * Default is false.
      */
-    EbBool enable_manual_pred_struct;
-
+    Bool enable_qm;
     /**
-     * @brief API signal specifying the size (number of entries) of the manual prediction structure buffer.
-     * Only checked and used when enable_manual_pred_struct is enabled.
-     *
-     * Min is 1.
-     * Max is 32.
-     * Default is 0.
+     * @brief Min quant matrix flatness. Applicable when enable_qm is true.
+     * Min value is 0.
+     * Max value is 15.
+     * Default is 8.
      */
-    int32_t manual_pred_struct_entry_num;
-
-    // Color description
-    /* Color description present flag
-    *
-    * It is not necessary to set this parameter manually.
-    * It is set internally to true once one of the color_primaries, transfer_characteristics or
-    * matrix coefficients is set to non-default value.
-    *
-    Default is false. */
-    EbBool color_description_present_flag;
-    /* Color primaries
-    * values are from EbColorPrimaries
-    Default is 2 (CP_UNSPECIFIED). */
-    uint8_t color_primaries;
-    /* Transfer characteristics
-    * values are from EbTransferCharacteristics
-    Default is 2 (TC_UNSPECIFIED). */
-    uint8_t transfer_characteristics;
-    /* Matrix coefficients
-    * values are from EbMatrixCoefficients
-    Default is 2 (MC_UNSPECIFIED). */
-    uint8_t matrix_coefficients;
-    /* Color range
-    * values are from EbColorRange
-    * 0: studio swing.
-    * 1: full swing.
-    Default is 0. */
-    uint8_t color_range;
-    /* Mastering display metadata
-    * values are from set using svt_aom_parse_mastering_display()
-    */
-    struct EbSvtAv1MasteringDisplayInfo mastering_display;
-    /* Content light level
-    * values are from set using svt_aom_parse_content_light_level()
-    */
-    struct EbContentLightLevel content_light_level;
-    /* Decoder speed optimization level
-    * 0: No decoder speed optimization
-    * 1: Low-level decoder speed optimization (fast decode)
-    * 2: Medium-level decoder speed optimization (faster decode)
-    * 3: High-level decoder speed optimization (fastest decode)
-    */
-    uint8_t fast_decode;
+    uint8_t min_qm_level;
+    /**
+     * @brief Max quant matrix flatness. Applicable when enable_qm is true.
+     * Min value is 0.
+     * Max value is 15.
+     * Default is 15.
+     */
+    uint8_t max_qm_level;
 } EbSvtAv1EncConfiguration;
 
 /**
